summaryrefslogtreecommitdiffstats
path: root/kspread/kspread_editors.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kspread/kspread_editors.cc')
-rw-r--r--kspread/kspread_editors.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/kspread/kspread_editors.cc b/kspread/kspread_editors.cc
index c9948189..ddf41d31 100644
--- a/kspread/kspread_editors.cc
+++ b/kspread/kspread_editors.cc
@@ -1195,7 +1195,7 @@ bool CellEditor::eventFilter( TQObject* o, TQEvent* e )
k->key() == Key_Return || k->key() == Key_Enter)
{
// Send directly to canvas
- TQApplication::sendEvent( tqparent(), e );
+ TQApplication::sendEvent( parent(), e );
return true;
}
}
@@ -1213,10 +1213,10 @@ bool CellEditor::eventFilter( TQObject* o, TQEvent* e )
// editor leaves editing mode ... otherwise editing is annoying
// left/right arrows still work with the F2-editor.
// Forward left & right arrows to tqparent, unless this editor has been set to capture arrow key events
// Changed to this behaviour for consistancy with OO Calc & MS Office.
if ( ((k->key() == TQt::Key_Left) || (k->key() == TQt::Key_Right)) && (!d->captureAllKeyEvents)) {
- TQApplication::sendEvent (tqparent(), e);
+ TQApplication::sendEvent (parent(), e);
return true;
}
}
@@ -1398,7 +1398,7 @@ void LocationEditWidget::keyPressEvent( TQKeyEvent * _ev )
if ( _ev->state() & ( TQt::AltButton | TQt::ControlButton ) )
{
TQLineEdit::keyPressEvent( _ev );
// Never allow that keys are passed on to the tqparent.
_ev->accept();
return;
@@ -1433,7 +1433,7 @@ void LocationEditWidget::keyPressEvent( TQKeyEvent * _ev )
break;
default:
TQLineEdit::keyPressEvent( _ev );
// Never allow that keys are passed on to the tqparent.
_ev->accept();
}
}
@@ -1213,10 +1213,10 @@ bool CellEditor::eventFilter( TQObject* o, TQEvent* e )
// editor leaves editing mode ... otherwise editing is annoying
// left/right arrows still work with the F2-editor.
- // Forward left & right arrows to tqparent, unless this editor has been set to capture arrow key events
+ // Forward left & right arrows to parent, unless this editor has been set to capture arrow key events
// Changed to this behaviour for consistancy with OO Calc & MS Office.
if ( ((k->key() == TQt::Key_Left) || (k->key() == TQt::Key_Right)) && (!d->captureAllKeyEvents)) {
@@ -1398,7 +1398,7 @@ void LocationEditWidget::keyPressEvent( TQKeyEvent * _ev )
{
TQLineEdit::keyPressEvent( _ev );
- // Never allow that keys are passed on to the tqparent.
+ // Never allow that keys are passed on to the parent.
_ev->accept();
return;
@@ -1433,7 +1433,7 @@ void LocationEditWidget::keyPressEvent( TQKeyEvent * _ev )
default:
TQLineEdit::keyPressEvent( _ev );
- // Never allow that keys are passed on to the tqparent.
+ // Never allow that keys are passed on to the parent.
_ev->accept();
}